Crate nucypher_core

Crate nucypher_core 

A collection of objects defining the protocol for NyCypher nodes (Ursulas).

Re-exports

pub use umbral_pre;
pub use ferveo;

Structs

AccessControlPolicy
Access control policy data for encrypted data.
Address
Represents an Ethereum address (20 bytes).
AuthenticatedData
Authenticated data for encrypted data.
Conditions
Access control conditions.
Context
Context for reencryption conditions.
EncryptedKeyFrag
Encrypted and signed key frag.
EncryptedThresholdDecryptionRequest
An encrypted request for an Ursula to derive a decryption share.
EncryptedThresholdDecryptionResponse
An encrypted response from Ursula with a derived decryption share.
EncryptedThresholdSignatureRequest
An encrypted signature request for Ursula to process and sign.
EncryptedThresholdSignatureResponse
An encrypted response from Ursula with a signature.
EncryptedTreasureMap
A treasure map encrypted for Bob.
FleetStateChecksum
An identifier of the fleet state.
HRAC
“hashed resource access code”.
MessageKit
Encrypted message prepared for re-encryption.
MetadataRequest
A request for metadata exchange.
MetadataResponse
A response returned by an Ursula containing known node metadata.
MetadataResponsePayload
Payload of the metadata response.
NodeMetadata
Signed node metadata.
NodeMetadataPayload
Node metadata.
PackedUserOperation
Packed UserOperation for signature requests
PackedUserOperationSignatureRequest
Packed UserOperation signature request
ReencryptionRequest
A request for an Ursula to reencrypt for several capsules.
ReencryptionResponse
A response from Ursula with reencrypted capsule frags.
RetrievalKit
An object encapsulating the information necessary for retrieval of cfrags from Ursulas. Contains the capsule and the checksum addresses of Ursulas from which the requester already received cfrags.
RevocationOrder
Represents a string used by characters to perform a revocation on a specific Ursula.
SessionSecretFactory
This class handles keyring material for session keys, by allowing deterministic derivation of SessionStaticSecret objects based on labels.
SessionSharedSecret
A Diffie-Hellman shared secret
SessionStaticKey
A session public key.
SessionStaticSecret
A session secret key.
SignatureResponse
Signature response
ThresholdDecryptionRequest
A request for an Ursula to derive a decryption share.
ThresholdDecryptionResponse
A response from Ursula with a derived decryption share.
ThresholdMessageKit
Access control metadata for encrypted data.
TreasureMap
A structure containing KeyFrag objects encrypted for Ursulas chosen for this policy.
Uint256
A wrapper around U256.
UserOperation
UserOperation for signature requests - https://eips.ethereum.org/EIPS/eip-4337
UserOperationSignatureRequest
UserOperation signature request
VerificationError
Error returned by various verify() methods in the crate.

Enums

AAVersion
AA version enum for Account Abstraction versions
DecryptionError
Errors during decryption.
DirectSignatureRequest
Enum to hold any type of signature request for direct returns
EncryptionError
Errors during encryption.
SignatureRequestType
Enum for different signature types.

Traits

BaseSignatureRequest
Base trait for signature requests
ProtocolObject
This is a versioned protocol object.

Functions

deserialize_signature_request
Utility function to deserialize any signature request from bytes
encrypt_for_dkg
Encrypt data based on conditions and dkg public key.