HRAC

Struct HRAC 

pub struct HRAC(/* private fields */);
“hashed resource access code”.

A hash of:

  • Publisher’s verifying key
  • Bob’s verifying key
  • the label

Publisher and Bob have all the information they need to construct this. Ursula does not, so we share it with her.

Implementations

Source

impl HRAC

pub const SIZE: usize = 16

The size of HRAC in bytes.

pub fn new( publisher_verifying_key: &PublicKey, bob_verifying_key: &PublicKey, label: &[u8], ) -> Self

Creates a new HRAC.