pub struct MetadataResponsePayload {
pub timestamp_epoch: u32,
pub announce_nodes: Box<[NodeMetadata]>,
}Expand description
Payload of the metadata response.
Fields
timestamp_epoch: u32The timestamp of the most recent fleet state (the one consisting of the nodes that are being sent).
announce_nodes: Box<[NodeMetadata]>A list of node metadata to announce.
Implementations
Sourceimpl MetadataResponsePayload
impl MetadataResponsePayload
Sourcepub fn new(timestamp_epoch: u32, announce_nodes: &[NodeMetadata]) -> Self
pub fn new(timestamp_epoch: u32, announce_nodes: &[NodeMetadata]) -> Self
Creates the new metadata response payload.