pub struct NodeMetadataPayload {
pub staking_provider_address: Address,
pub domain: String,
pub timestamp_epoch: u32,
pub verifying_key: PublicKey,
pub encrypting_key: PublicKey,
pub ferveo_public_key: ValidatorPublicKey,
pub certificate_der: Box<[u8]>,
pub host: String,
pub port: u16,
pub operator_signature: RecoverableSignature,
}Expand description
Node metadata.
Fields
staking_provider_address: AddressThe staking provider’s Ethereum address.
domain: StringThe network identifier.
timestamp_epoch: u32The timestamp of the metadata creation.
verifying_key: PublicKeyThe node’s verifying key.
encrypting_key: PublicKeyThe node’s encrypting key.
ferveo_public_key: ValidatorPublicKeyFerveo public key to use for DKG participation.
certificate_der: Box<[u8]>The node’s SSL certificate (serialized in DER format).
host: StringThe hostname of the node’s REST service.
port: u16The port of the node’s REST service.
operator_signature: RecoverableSignatureThe node’s verifying key signed by the private key corresponding to the operator address.
Implementations
Sourceimpl NodeMetadataPayload
impl NodeMetadataPayload
Sourcepub fn derive_operator_address(&self) -> Result<Address, AddressDerivationError>
pub fn derive_operator_address(&self) -> Result<Address, AddressDerivationError>
Derives the address corresponding to the public key that was used
to create operator_signature.