pub struct RetrievalKit {
pub capsule: Capsule,
pub queried_addresses: BTreeSet<Address>,
pub conditions: Option<Conditions>,
}Expand description
An object encapsulating the information necessary for retrieval of cfrags from Ursulas. Contains the capsule and the checksum addresses of Ursulas from which the requester already received cfrags.
Fields
capsule: CapsuleThe ciphertext’s capsule.
queried_addresses: BTreeSet<Address>The addresses that have already been queried for reencryption.
conditions: Option<Conditions>A blob of bytes containing decryption conditions for this message.
Implementations
Sourceimpl RetrievalKit
impl RetrievalKit
Sourcepub fn from_message_kit(message_kit: &MessageKit) -> Self
pub fn from_message_kit(message_kit: &MessageKit) -> Self
Creates a new retrieval kit from a message kit.
Sourcepub fn new(
capsule: &Capsule,
queried_addresses: impl IntoIterator<Item = Address>,
conditions: Option<&Conditions>,
) -> Self
pub fn new( capsule: &Capsule, queried_addresses: impl IntoIterator<Item = Address>, conditions: Option<&Conditions>, ) -> Self
Creates a new retrieval kit recording the addresses already queried for reencryption.