pub struct ThresholdDecryptionRequest {
pub ritual_id: u32,
pub ciphertext_header: CiphertextHeader,
pub acp: AccessControlPolicy,
pub context: Option<Context>,
pub variant: FerveoVariant,
}Expand description
A request for an Ursula to derive a decryption share.
Fields
ritual_id: u32The ID of the ritual.
ciphertext_header: CiphertextHeaderThe ciphertext to generate a decryption share for.
acp: AccessControlPolicyThe associated access control metadata.
context: Option<Context>A blob of bytes containing context required to evaluate conditions.
variant: FerveoVariantThe ferveo variant to use for the decryption share derivation.
Implementations
Sourceimpl ThresholdDecryptionRequest
impl ThresholdDecryptionRequest
Sourcepub fn new(
ritual_id: u32,
ciphertext_header: &CiphertextHeader,
acp: &AccessControlPolicy,
context: Option<&Context>,
variant: FerveoVariant,
) -> Self
pub fn new( ritual_id: u32, ciphertext_header: &CiphertextHeader, acp: &AccessControlPolicy, context: Option<&Context>, variant: FerveoVariant, ) -> Self
Creates a new decryption request.
Sourcepub fn encrypt(
&self,
shared_secret: &SessionSharedSecret,
requester_public_key: &SessionStaticKey,
) -> EncryptedThresholdDecryptionRequest
pub fn encrypt( &self, shared_secret: &SessionSharedSecret, requester_public_key: &SessionStaticKey, ) -> EncryptedThresholdDecryptionRequest
Encrypts the decryption request.