pub struct TreasureMap {
pub threshold: u8,
pub hrac: HRAC,
pub destinations: BTreeMap<Address, EncryptedKeyFrag>,
pub policy_encrypting_key: PublicKey,
pub publisher_verifying_key: PublicKey,
}Expand description
A structure containing KeyFrag objects encrypted for Ursulas chosen for this policy.
Fields
threshold: u8Threshold for successful re-encryption.
hrac: HRACPolicy HRAC.
destinations: BTreeMap<Address, EncryptedKeyFrag>Encrypted key frags assigned to target Ursulas.
policy_encrypting_key: PublicKeyA key to create encrypted messages under this policy.
publisher_verifying_key: PublicKeyPublisher’s verifying key.
Implementations
Sourceimpl TreasureMap
impl TreasureMap
Sourcepub fn new(
signer: &Signer,
hrac: &HRAC,
policy_encrypting_key: &PublicKey,
assigned_kfrags: impl IntoIterator<Item = (Address, (PublicKey, VerifiedKeyFrag))>,
threshold: u8,
) -> Self
pub fn new( signer: &Signer, hrac: &HRAC, policy_encrypting_key: &PublicKey, assigned_kfrags: impl IntoIterator<Item = (Address, (PublicKey, VerifiedKeyFrag))>, threshold: u8, ) -> Self
Create a new treasure map for a collection of ursulas and kfrags.
Panics if threshold is set to 0,
the number of assigned keyfrags is less than threshold,
or if the addresses in assigned_kfrags repeat.
Sourcepub fn encrypt(
&self,
signer: &Signer,
recipient_key: &PublicKey,
) -> EncryptedTreasureMap
pub fn encrypt( &self, signer: &Signer, recipient_key: &PublicKey, ) -> EncryptedTreasureMap
Encrypts the treasure map for Bob.
Sourcepub fn make_revocation_orders(&self, signer: &Signer) -> Vec<RevocationOrder>
pub fn make_revocation_orders(&self, signer: &Signer) -> Vec<RevocationOrder>
Makes revocation orders for all destinations in the treasure map.